init_mean_score
===================================================

.. currentmodule:: skchange.scores

.. autofunction:: init_mean_score

.. include:: skchange.scores.init_mean_score.examples

.. raw:: html

    <div class="clearer"></div>